==> public-sdk-2.0.21-sources.jar: com/voxeet/sdk/json/ExternalAuthStateEvent.java <==
package com.voxeet.sdk.json;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonProperty;

@JsonIgnoreProperties(ignoreUnknown = true)
public class ExternalAuthStateEvent extends Event {

    private String timezone;

    @JsonProperty("push_token")
    private String pushToken;

    @JsonProperty("device_identifier")
    private String deviceIdentifier;

    @JsonProperty("device_type")
    private String deviceType;

    public ExternalAuthStateEvent(String pushToken, String deviceIdentifier, String timezone) {
        this.timezone = timezone;

        this.pushToken = pushToken;

        this.deviceIdentifier = deviceIdentifier;

        this.deviceType = "ANDROID";
    }

    public String getPushToken() {
        return pushToken;
    }

    public void setPushToken(String pushToken) {
        this.pushToken = pushToken;
    }

    public String getDeviceIdentifier() {
        return deviceIdentifier;
    }

    public void setDeviceIdentifier(String deviceIdentifier) {
        this.deviceIdentifier = deviceIdentifier;
    }

    public String getDeviceType() {
        return deviceType;
    }

    public void setDeviceType(String deviceType) {
        this.deviceType = deviceType;
    }

    public String getTimezone() {
        return timezone;
    }

    public void setTimezone(String timezone) {
        this.timezone = timezone;
    }

    @Override
    public String getType() {
        return EventNames.STATE_GENERATOR;
    }
}

==> public-sdk-2.0.68-sources.jar: com/voxeet/sdk/json/ExternalAuthStateEvent.java <==
package com.voxeet.sdk.json;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.voxeet.sdk.utils.Annotate;
import com.voxeet.sdk.utils.FromWebsocket;
import com.voxeet.sdk.utils.ToDelete;

@ToDelete
@Annotate
@FromWebsocket
@JsonIgnoreProperties(ignoreUnknown = true)
public class ExternalAuthStateEvent extends Event {

    private String timezone;

    @JsonProperty("push_token")
    private String pushToken;

    @JsonProperty("device_identifier")
    private String deviceIdentifier;

    @JsonProperty("device_type")
    private String deviceType;

    public ExternalAuthStateEvent(String pushToken, String deviceIdentifier, String timezone) {
        this.timezone = timezone;

        this.pushToken = pushToken;

        this.deviceIdentifier = deviceIdentifier;

        this.deviceType = "ANDROID";
    }

    public String getPushToken() {
        return pushToken;
    }

    public void setPushToken(String pushToken) {
        this.pushToken = pushToken;
    }

    public String getDeviceIdentifier() {
        return deviceIdentifier;
    }

    public void setDeviceIdentifier(String deviceIdentifier) {
        this.deviceIdentifier = deviceIdentifier;
    }

    public String getDeviceType() {
        return deviceType;
    }

    public void setDeviceType(String deviceType) {
        this.deviceType = deviceType;
    }

    public String getTimezone() {
        return timezone;
    }

    public void setTimezone(String timezone) {
        this.timezone = timezone;
    }

    @Override
    public String getType() {
        return EventNames.STATE_GENERATOR;
    }
}
